@@ -10,7 +10,7 @@ class PFMain:
     def __init__(
         self,
         n_tasks=2,
-        mesh_size=10,
+        pf_mesh=30,
         bounds=np.array([[0, 1.0], [0, 1.0]]),
         pf_optimal_solution=True,
         pf_correlation_maps=True,
@@ -32,7 +32,7 @@ class PFMain:
         n_tasks : int
             The number of objectives to optimize.
 
-        mesh_size : int
+        pf_mesh : int
             The size of the discretized data for each model.
 
         bounds : ndarray
@@ -49,12 +49,12 @@ class PFMain:
         """
 
         self.n_tasks = n_tasks
-        self.mesh_size = mesh_size
+        self.pf_mesh = pf_mesh
         self.bounds = bounds
         self.n_dim = np.shape(self.bounds)[0]
         self.models = models
-        self.n_mesh = (self.mesh_size,) * self.n_dim
-        self.mesher = Mesh(self.bounds, grid_pts=self.mesh_size)
+        self.n_mesh = (self.pf_mesh,) * self.n_dim
+        self.mesher = Mesh(self.bounds, grid_pts=self.pf_mesh)
         self.X_mg = self.mesher.grid
         self.pf_optimal_solution = pf_optimal_solution
         self.pf_optimal_weights = pf_optimal_weights
@@ -104,7 +104,7 @@ class PFMain:
              The bounds for each model.
 
          n_mesh : ndarray
-             An array of shape mesh_size * model dimension
+             An array of shape pf_mesh * model dimension
 
         Returns
         -------
