@@ -484,7 +484,7 @@ class BenchmarkDatabase:
         # If we only use a subset of BOSS keywords as columns we
         # filter those keywords here.
         if self._keyword_cols:
-            settings = {k: bo_settings[k] for k in self._keyword_cols}
+            settings = {k: v for k, v in bo_settings.items() if k in self._keyword_cols}
         else:
             settings = bo_settings
 
